Re: [PATCH][v2] dmaengine: s3c24xx: Fix spelling mistake in dev_err mistake

2015-03-02 Thread Vinod Koul
On Sat, Feb 28, 2015 at 10:25:06PM +, Colin King wrote:
> From: Colin Ian King 
> 
> Fix spelling mistake, "aquire" -> "acquire" and missing newline (as
> spotted by Joe Perches.
> 
Applied, thanks

-- 
~Vinod

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: [PATCH][v2] dmaengine: s3c24xx: Fix spelling mistake in dev_err mistake

2015-03-02 Thread Vinod Koul
On Sat, Feb 28, 2015 at 10:25:06PM +, Colin King wrote:
 From: Colin Ian King colin.k...@canonical.com
 
 Fix spelling mistake, aquire - acquire and missing newline (as
 spotted by Joe Perches.
 
Applied, thanks

-- 
~Vinod

--
To unsubscribe from this list: send the line unsubscribe linux-kernel in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


[PATCH][v2] dmaengine: s3c24xx: Fix spelling mistake in dev_err mistake

2015-02-28 Thread Colin King
From: Colin Ian King 

Fix spelling mistake, "aquire" -> "acquire" and missing newline (as
spotted by Joe Perches.

Signed-off-by: Colin Ian King 
---
 drivers/dma/s3c24xx-dma.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/dma/s3c24xx-dma.c b/drivers/dma/s3c24xx-dma.c
index 2f91da3..4eae6d5 100644
--- a/drivers/dma/s3c24xx-dma.c
+++ b/drivers/dma/s3c24xx-dma.c
@@ -1238,7 +1238,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
if (!s3cdma->phy_chans)
return -ENOMEM;
 
    /* aquire irqs and clocks for all physical channels */
for (i = 0; i < pdata->num_phy_channels; i++) {
struct s3c24xx_dma_phy *phy = >phy_chans[i];
char clk_name[6];
@@ -1266,7 +1266,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
sprintf(clk_name, "dma.%d", i);
phy->clk = devm_clk_get(>dev, clk_name);
if (IS_ERR(phy->clk) && sdata->has_clocks) {
-   dev_err(>dev, "unable to aquire clock for 
channel %d, error %lu",
+   dev_err(>dev, "unable to acquire clock 
@@ -1238,7 +1238,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
return -ENOMEM;
 
-   /* aquire irqs and clocks for all physical channels */
+   /* acquire irqs and clocks for all physical channels */
for (i = 0; i < pdata->num_phy_channels; i++) {
struct s3c24xx_dma_phy *phy = >phy_chans[i];
for channel %d, error %lu\n",
i, PTR_ERR(phy->clk));
continue;
}
-- 
2.1.4

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


[PATCH][v2] dmaengine: s3c24xx: Fix spelling mistake in dev_err mistake

2015-02-28 Thread Colin King
From: Colin Ian King colin.k...@canonical.com

Fix spelling mistake, aquire - acquire and missing newline (as
spotted by Joe Perches.

Signed-off-by: Colin Ian King colin.k...@canonical.com
---
 drivers/dma/s3c24xx-dma.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/dma/s3c24xx-dma.c b/drivers/dma/s3c24xx-dma.c
index 2f91da3..4eae6d5 100644
--- a/drivers/dma/s3c24xx-dma.c
+++ b/drivers/dma/s3c24xx-dma.c
@@ -1238,7 +1238,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
if (!s3cdma-phy_chans)
return -ENOMEM;
 
    /* aquire irqs and clocks for all physical channels */
for (i = 0; i  pdata-num_phy_channels; i++) {
struct s3c24xx_dma_phy *phy = s3cdma-phy_chans[i];
char clk_name[6];
@@ -1266,7 +1266,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
sprintf(clk_name, dma.%d, i);
phy-clk = devm_clk_get(pdev-dev, clk_name);
if (IS_ERR(phy-clk)  sdata-has_clocks) {
-   dev_err(pdev-dev, unable to aquire clock for 
channel %d, error %lu,
+   dev_err(pdev-dev, unable to acquire clock 
@@ -1238,7 +1238,7 @@ static int s3c24xx_dma_probe(struct platform_device *pdev)
return -ENOMEM;
 
-   /* aquire irqs and clocks for all physical channels */
+   /* acquire irqs and clocks for all physical channels */
for (i = 0; i  pdata-num_phy_channels; i++) {
struct s3c24xx_dma_phy *phy = s3cdma-phy_chans[i];
for channel %d, error %lu\n,
i, PTR_ERR(phy-clk));
continue;
}
-- 
2.1.4

--
To unsubscribe from this list: send the line unsubscribe linux-kernel in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/